@@ -311,7 +311,7 @@
     <message>
         <location filename="../src/core/ui/mainwindow.ui" line="203"/>
         <source>Zoom area around mouse</source>
-        <translation>Přiblížit oblast okolo ukazatele myši</translation>
+        <translation>Přiblížit oblast okolo ukazovátka myši</translation>
     </message>
     <message>
         <location filename="../src/core/ui/mainwindow.ui" line="210"/>
@@ -321,7 +321,7 @@
     <message>
         <location filename="../src/core/ui/mainwindow.ui" line="217"/>
         <source>Include mouse pointer</source>
-        <translation>Včetně ukazatele myši</translation>
+        <translation>Včetně ukazovátka myši</translation>
     </message>
     <message>
         <location filename="../src/core/ui/mainwindow.ui" line="246"/>
@@ -372,7 +372,7 @@
     <message>
         <location filename="../src/core/ui/mainwindow.cpp" line="345"/>
         <source>Double click to open screenshot in external default image viewer</source>
-        <translation>Dvojklikem snímek otevřít ve výchozím prohlížeči obrázků</translation>
+        <translation>Dvojklepnutím snímek otevřít ve výchozím prohlížeči obrázků</translation>
     </message>
     <message>
         <location filename="../src/core/ui/mainwindow.cpp" line="354"/>
@@ -404,10 +404,10 @@
 right click to fit to edges,
 double click or press Enter
 to take a screenshot.</source>
-        <translation>Klikněte a natáhněte obdélník,
-kliknutím pravým tlačítkem
+        <translation>Klepněte a natáhněte obdélník,
+klepnutím pravým tlačítkem
 přizpůsobte hranám,
-dvojklikem nebo stiskem klávesy
+dvojklepnutím nebo stiskem klávesy
 Enter pořiďte snímek obrazovky.</translation>
     </message>
     <message>
@@ -593,7 +593,7 @@ Enter pořiďte snímek obrazovky.</translation>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="397"/>
         <source>Open in external viewer on double click</source>
-        <translation>Při dvojkliku otevřít v externím prohlížeči</translation>
+        <translation>Při dvojklepnutí otevřít v externím prohlížeči</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="400"/>
@@ -610,7 +610,7 @@ se může zvětšit aby obsáhla vnější hrany</translation>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="411"/>
         <source>Fit to edges inside selected area by right clicking</source>
-        <translation>Kliknutím pravým tlačítkem uvnitř oblasti výběru přizpůsobíte hranám</translation>
+        <translation>Klepnutím pravým tlačítkem uvnitř oblasti výběru přizpůsobíte hranám</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="449"/>
