@@ -404,7 +404,10 @@
 right click to fit to edges,
 double click or press Enter
 to take a screenshot.</source>
-        <translation type="unfinished"></translation>
+        <translation>יש ללחוץ ולגרור כדי לצייר מרובע,
+כפתור ימני כדי להיצמד לקצוות,
+לחיצה כפולה או לחיצה על Enter
+כדי לצלם.</translation>
     </message>
     <message>
         <location filename="../src/core/regionselect.cpp" line="202"/>
@@ -600,12 +603,13 @@ to take a screenshot.</source>
         <location filename="../src/core/ui/configwidget.ui" line="407"/>
         <source>If this is unchecked, the selected area
 might become larger to fit to outer edges</source>
-        <translation type="unfinished"></translation>
+        <translation>אם אפשרות זו לא מסומנת, השטח הנבחר
+עשוי לגדול כדי ללכוד את המסגרת החיצונית</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="411"/>
         <source>Fit to edges inside selected area by right clicking</source>
-        <translation type="unfinished"></translation>
+        <translation>הצמדה למסגרת בתוך השטח הנבחר על ידי לחיצה ימנית</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="449"/>
@@ -680,7 +684,7 @@ might become larger to fit to outer edges</source>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="593"/>
         <source>Full screen</source>
-        <translation type="unfinished">מסך מלא</translation>
+        <translation>מסך מלא</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="598"/>
