@@ -404,7 +404,9 @@
 right click to fit to edges,
 double click or press Enter
 to take a screenshot.</source>
-        <translation type="unfinished"></translation>
+        <translation>Clique e arraste para criar um retângulo,
+botão direito do rato para ajustar às margens,
+duplo clique ou Enter para obter a captura.</translation>
     </message>
     <message>
         <location filename="../src/core/regionselect.cpp" line="202"/>
@@ -600,12 +602,13 @@ to take a screenshot.</source>
         <location filename="../src/core/ui/configwidget.ui" line="407"/>
         <source>If this is unchecked, the selected area
 might become larger to fit to outer edges</source>
-        <translation type="unfinished"></translation>
+        <translation>Se desativar a opção, a área selecionada
+pode ficar maior para se ajustar às margens</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="411"/>
         <source>Fit to edges inside selected area by right clicking</source>
-        <translation type="unfinished"></translation>
+        <translation>Ajuste as arestas da área selecionada clicando com o botão direito</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="449"/>
